@@ -1,6 +1,7 @@
 /*
   Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
-  2004, 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+  2004, 2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation,
+  Inc.
 
   This file is part of GNU Inetutils.
 
@@ -54,9 +55,7 @@
 #endif
 
 #include <sys/param.h>
-#ifdef HAVE_SYS_WAIT_H
-# include <sys/wait.h>
-#endif
+#include <sys/wait.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -73,26 +72,18 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#ifdef TIME_WITH_SYS_TIME
-# include <sys/time.h>
-# include <time.h>
-#else
-# ifdef HAVE_SYS_TIME_H
-#  include <sys/time.h>
-# else
-#  include <time.h>
-# endif
-#endif
+#include <sys/time.h>
+#include <time.h>
 #include <unistd.h>
 /* Include glob.h last, because it may define "const" which breaks
    system headers on some platforms. */
 #include <glob.h>
 
 #if HAVE_LIBREADLINE
-#  include <readline/readline.h>
-#  include <readline/history.h>
+# include <readline/readline.h>
+# include <readline/history.h>
 #else
-#  include "readline.h"
+# include "readline.h"
 #endif
 
 #include "ftp_var.h"
