@@ -1,6 +1,7 @@
 /*
   Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
-  2004, 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+  2004, 2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation,
+  Inc.
 
   This file is part of GNU Inetutils.
 
@@ -78,10 +79,10 @@
 #include "libinetutils.h"
 
 #if HAVE_LIBREADLINE
-#  include <readline/readline.h>
-#  include <readline/history.h>
+# include <readline/readline.h>
+# include <readline/history.h>
 #else
-#  include "readline.h"
+# include "readline.h"
 #endif
 
 
@@ -91,6 +92,10 @@ static char *prompt = 0;
 const char args_doc[] = "[HOST [PORT]]";
 const char doc[] = "Remote file transfer.";
 
+enum {
+  OPT_PROMPT = CHAR_MAX + 1,
+};
+
 static struct argp_option argp_options[] = {
 #define GRP 0
   {"debug", 'd', NULL, 0, "set the SO_DEBUG option", GRP+1},
@@ -100,7 +105,9 @@ static struct argp_option argp_options[] = {
   {"no-login", 'n', NULL, 0, "do not automatically login to the remote system",
    GRP+1},
   {"trace", 't', NULL, 0, "enable packet tracing", GRP+1},
-  {"prompt", 'p', "PROMPT", OPTION_ARG_OPTIONAL, "print a command line PROMPT "
+  {"passive", 'p', NULL, 0, "enable passive mode transfer", GRP+1},
+  {"active", 'A', NULL, 0, "enable active mode transfer", GRP+1},
+  {"prompt", OPT_PROMPT, "PROMPT", OPTION_ARG_OPTIONAL, "print a command line PROMPT "
    "(optionally), even if not on a tty", GRP+1},
   {"verbose", 'v', NULL, 0, "verbose output", GRP+1},
 #undef GRP
@@ -137,10 +144,18 @@ parse_opt (int key, char *arg, struct argp_state *state)
       verbose++;
       break;
 
-    case 'p':		/* Print command line prompt.  */
+    case OPT_PROMPT:		/* Print command line prompt.  */
       prompt = arg ? arg : DEFAULT_PROMPT;
       break;
 
+    case 'p':		/* Enable passive transfer mode.  */
+      passivemode = 1;
+      break;
+
+    case 'A':	/* Enable active transfer mode.  */
+      passivemode = 0;
+      break;
+
     default:
       return ARGP_ERR_UNKNOWN;
     }
@@ -160,13 +175,11 @@ main (int argc, char *argv[])
   char *cp;
 
   set_program_name (argv[0]);
-  
-  sp = getservbyname ("ftp", "tcp");
-  if (sp == 0)
-    error (EXIT_FAILURE, 0, "ftp/tcp: unknown service");
+
   doglob = 1;
   interactive = 1;
   autologin = 1;
+  passivemode = 0;		/* passive mode not active */
 
   /* Parse command line */
   iu_argp_init ("ftp", default_program_authors);
@@ -175,6 +188,10 @@ main (int argc, char *argv[])
   argc -= index;
   argv += index;
 
+  sp = getservbyname ("ftp", "tcp");
+  if (sp == 0)
+    error (EXIT_FAILURE, 0, "ftp/tcp: unknown service");
+
   fromatty = isatty (fileno (stdin));
   if (fromatty)
     {
@@ -185,7 +202,6 @@ main (int argc, char *argv[])
 
   cpend = 0;			/* no pending replies */
   proxy = 0;			/* proxy not active */
-  passivemode = 0;		/* passive mode not active */
   crflag = 1;			/* strip c.r. on ascii gets */
   sendport = -1;		/* not using ports */
   /*
