@@ -1,3 +1,22 @@
+/*
+  Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008,
+  2009, 2010 Free Software Foundation, Inc.
+
+  This file is part of GNU Inetutils.
+
+  GNU Inetutils is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or (at
+  your option) any later version.
+
+  GNU Inetutils is distributed in the hope that it will be useful, but
+  WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see `http://www.gnu.org/licenses/'. */
+
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
@@ -14,16 +33,8 @@
 #ifdef HAVE_SHADOW_H
 # include <shadow.h>
 #endif
-#ifdef TIME_WITH_SYS_TIME
-# include <sys/time.h>
-# include <time.h>
-#else
-# ifdef HAVE_SYS_TIME_H
-#  include <sys/time.h>
-# else
-#  include <time.h>
-# endif
-#endif
+#include <sys/time.h>
+#include <time.h>
 
 #include "extern.h"
 
@@ -62,8 +73,7 @@ auth_user (const char *name, struct credentials *pcred)
     default:
       {
 	size_t len;
-	if (pcred->message)
-	  free (pcred->message);
+	free (pcred->message);
 	len = (size_t) (64 + strlen (name));
 	pcred->message = malloc (len);
 	if (pcred->message == NULL)
@@ -175,16 +185,11 @@ sgetcred (const char *name, struct credentials *pcred)
   if (p == NULL)
     return 1;
 
-  if (pcred->name)
-    free (pcred->name);
-  if (pcred->passwd)
-    free (pcred->passwd);
-  if (pcred->homedir)
-    free (pcred->homedir);
-  if (pcred->rootdir)
-    free (pcred->rootdir);
-  if (pcred->shell)
-    free (pcred->shell);
+  free (pcred->name);
+  free (pcred->passwd);
+  free (pcred->homedir);
+  free (pcred->rootdir);
+  free (pcred->shell);
 
 #if defined(HAVE_GETSPNAM) && defined(HAVE_SHADOW_H)
   if (p->pw_passwd == NULL || strlen (p->pw_passwd) == 1)
