@@ -68,7 +68,7 @@
 /* Copy the first part of user declarations.  */
 
 /* Line 189 of yacc.c  */
-#line 35 "ftpcmd.y"
+#line 55 "ftpcmd.y"
 
 
 #ifdef HAVE_CONFIG_H
@@ -92,21 +92,11 @@
 #include <stdlib.h>
 #include <string.h>
 #include <syslog.h>
-#ifdef TIME_WITH_SYS_TIME
-# include <sys/time.h>
-# include <time.h>
-#else
-# ifdef HAVE_SYS_TIME_H
-#  include <sys/time.h>
-# else
-#  include <time.h>
-# endif
-#endif
+#include <sys/time.h>
+#include <time.h>
 #include <unistd.h>
 #include <limits.h>
-#ifdef HAVE_SYS_UTSNAME_H
 #include <sys/utsname.h>
-#endif
 /* Include glob.h last, because it may define "const" which breaks
    system headers on some platforms. */
 #include <glob.h>
@@ -146,7 +136,7 @@ static void yyerror       (const char *s);
 
 
 /* Line 189 of yacc.c  */
-#line 150 "ftpcmd.c"
+#line 140 "ftpcmd.c"
 
 /* Enabling traces.  */
 #ifndef YYDEBUG
@@ -311,7 +301,7 @@ typedef union YYSTYPE
 {
 
 /* Line 214 of yacc.c  */
-#line 111 "ftpcmd.y"
+#line 121 "ftpcmd.y"
 
 	int	i;
 	char   *s;
@@ -319,7 +309,7 @@ typedef union YYSTYPE
 
 
 /* Line 214 of yacc.c  */
-#line 323 "ftpcmd.c"
+#line 313 "ftpcmd.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -331,7 +321,7 @@ typedef union YYSTYPE
 
 
 /* Line 264 of yacc.c  */
-#line 335 "ftpcmd.c"
+#line 325 "ftpcmd.c"
 
 #ifdef short
 # undef short
@@ -657,14 +647,14 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   145,   145,   147,   153,   157,   162,   168,   190,   195,
-     230,   242,   254,   258,   262,   268,   274,   280,   285,   291,
-     296,   302,   308,   312,   318,   331,   335,   340,   346,   350,
-     366,   370,   376,   382,   387,   392,   396,   401,   411,   426,
-     439,   445,   461,   467,   512,   528,   549,   554,   560,   570,
-     584,   589,   592,   596,   600,   614,   618,   622,   629,   634,
-     639,   644,   649,   653,   658,   664,   672,   676,   680,   687,
-     691,   695,   702,   739,   743,   771
+       0,   155,   155,   157,   163,   167,   172,   178,   200,   205,
+     240,   252,   264,   268,   272,   278,   284,   290,   295,   301,
+     306,   312,   318,   322,   328,   341,   345,   350,   356,   360,
+     376,   380,   386,   392,   397,   402,   406,   411,   421,   436,
+     449,   455,   471,   477,   522,   538,   559,   564,   570,   580,
+     594,   599,   602,   606,   610,   624,   628,   632,   639,   644,
+     649,   654,   659,   663,   668,   674,   682,   686,   690,   697,
+     701,   705,   712,   749,   753,   781
 };
 #endif
 
@@ -1692,7 +1682,7 @@ yyreduce:
         case 3:
 
 /* Line 1455 of yacc.c  */
-#line 148 "ftpcmd.y"
+#line 158 "ftpcmd.y"
     {
 			free (fromname);
 			fromname = (char *) 0;
@@ -1703,7 +1693,7 @@ yyreduce:
   case 5:
 
 /* Line 1455 of yacc.c  */
-#line 158 "ftpcmd.y"
+#line 168 "ftpcmd.y"
     {
 			user((yyvsp[(3) - (4)].s));
 			free((yyvsp[(3) - (4)].s));
@@ -1713,7 +1703,7 @@ yyreduce:
   case 6:
 
 /* Line 1455 of yacc.c  */
-#line 163 "ftpcmd.y"
+#line 173 "ftpcmd.y"
     {
 			pass((yyvsp[(3) - (4)].s));
 			memset ((yyvsp[(3) - (4)].s), 0, strlen ((yyvsp[(3) - (4)].s)));
@@ -1724,7 +1714,7 @@ yyreduce:
   case 7:
 
 /* Line 1455 of yacc.c  */
-#line 169 "ftpcmd.y"
+#line 179 "ftpcmd.y"
     {
 			usedefault = 0;
 			if (pdata >= 0) {
@@ -1751,7 +1741,7 @@ yyreduce:
   case 8:
 
 /* Line 1455 of yacc.c  */
-#line 191 "ftpcmd.y"
+#line 201 "ftpcmd.y"
     {
 			if ((yyvsp[(2) - (3)].i))
 				passive();
@@ -1761,7 +1751,7 @@ yyreduce:
   case 9:
 
 /* Line 1455 of yacc.c  */
-#line 196 "ftpcmd.y"
+#line 206 "ftpcmd.y"
     {
 			switch (cmd_type) {
 
@@ -1801,7 +1791,7 @@ yyreduce:
   case 10:
 
 /* Line 1455 of yacc.c  */
-#line 231 "ftpcmd.y"
+#line 241 "ftpcmd.y"
     {
 			switch ((yyvsp[(3) - (4)].i)) {
 
@@ -1818,7 +1808,7 @@ yyreduce:
   case 11:
 
 /* Line 1455 of yacc.c  */
-#line 243 "ftpcmd.y"
+#line 253 "ftpcmd.y"
     {
 			switch ((yyvsp[(3) - (4)].i)) {
 
@@ -1835,7 +1825,7 @@ yyreduce:
   case 12:
 
 /* Line 1455 of yacc.c  */
-#line 255 "ftpcmd.y"
+#line 265 "ftpcmd.y"
     {
 			reply(202, "ALLO command ignored.");
 		}
@@ -1844,7 +1834,7 @@ yyreduce:
   case 13:
 
 /* Line 1455 of yacc.c  */
-#line 259 "ftpcmd.y"
+#line 269 "ftpcmd.y"
     {
 			reply(202, "ALLO command ignored.");
 		}
@@ -1853,7 +1843,7 @@ yyreduce:
   case 14:
 
 /* Line 1455 of yacc.c  */
-#line 263 "ftpcmd.y"
+#line 273 "ftpcmd.y"
     {
 			if ((yyvsp[(2) - (5)].i) && (yyvsp[(4) - (5)].s) != NULL)
 				retrieve((char *) 0, (yyvsp[(4) - (5)].s));
@@ -1864,7 +1854,7 @@ yyreduce:
   case 15:
 
 /* Line 1455 of yacc.c  */
-#line 269 "ftpcmd.y"
+#line 279 "ftpcmd.y"
     {
 			if ((yyvsp[(2) - (5)].i) && (yyvsp[(4) - (5)].s) != NULL)
 				store((yyvsp[(4) - (5)].s), "w", 0);
@@ -1875,7 +1865,7 @@ yyreduce:
   case 16:
 
 /* Line 1455 of yacc.c  */
-#line 275 "ftpcmd.y"
+#line 285 "ftpcmd.y"
     {
 			if ((yyvsp[(2) - (5)].i) && (yyvsp[(4) - (5)].s) != NULL)
 				store((yyvsp[(4) - (5)].s), "a", 0);
@@ -1886,7 +1876,7 @@ yyreduce:
   case 17:
 
 /* Line 1455 of yacc.c  */
-#line 281 "ftpcmd.y"
+#line 291 "ftpcmd.y"
     {
 			if ((yyvsp[(2) - (3)].i))
 				send_file_list(".");
@@ -1896,7 +1886,7 @@ yyreduce:
   case 18:
 
 /* Line 1455 of yacc.c  */
-#line 286 "ftpcmd.y"
+#line 296 "ftpcmd.y"
     {
 			if ((yyvsp[(2) - (5)].i) && (yyvsp[(4) - (5)].s) != NULL)
 				send_file_list((yyvsp[(4) - (5)].s));
@@ -1907,7 +1897,7 @@ yyreduce:
   case 19:
 
 /* Line 1455 of yacc.c  */
-#line 292 "ftpcmd.y"
+#line 302 "ftpcmd.y"
     {
 			if ((yyvsp[(2) - (3)].i))
 				retrieve("/bin/ls -lgA", "");
@@ -1917,7 +1907,7 @@ yyreduce:
   case 20:
 
 /* Line 1455 of yacc.c  */
-#line 297 "ftpcmd.y"
+#line 307 "ftpcmd.y"
     {
 			if ((yyvsp[(2) - (5)].i) && (yyvsp[(4) - (5)].s) != NULL)
 				retrieve("/bin/ls -lgA %s", (yyvsp[(4) - (5)].s));
@@ -1928,7 +1918,7 @@ yyreduce:
   case 21:
 
 /* Line 1455 of yacc.c  */
-#line 303 "ftpcmd.y"
+#line 313 "ftpcmd.y"
     {
 			if ((yyvsp[(2) - (5)].i) && (yyvsp[(4) - (5)].s) != NULL)
 				statfilecmd((yyvsp[(4) - (5)].s));
@@ -1939,7 +1929,7 @@ yyreduce:
   case 22:
 
 /* Line 1455 of yacc.c  */
-#line 309 "ftpcmd.y"
+#line 319 "ftpcmd.y"
     {
 			statcmd();
 		}
@@ -1948,7 +1938,7 @@ yyreduce:
   case 23:
 
 /* Line 1455 of yacc.c  */
-#line 313 "ftpcmd.y"
+#line 323 "ftpcmd.y"
     {
 			if ((yyvsp[(2) - (5)].i) && (yyvsp[(4) - (5)].s) != NULL)
 				delete((yyvsp[(4) - (5)].s));
@@ -1959,7 +1949,7 @@ yyreduce:
   case 24:
 
 /* Line 1455 of yacc.c  */
-#line 319 "ftpcmd.y"
+#line 329 "ftpcmd.y"
     {
 		    if ((yyvsp[(2) - (5)].i)) {
 			if (fromname) {
@@ -1977,7 +1967,7 @@ yyreduce:
   case 25:
 
 /* Line 1455 of yacc.c  */
-#line 332 "ftpcmd.y"
+#line 342 "ftpcmd.y"
     {
 			reply(225, "ABOR command successful.");
 		}
@@ -1986,7 +1976,7 @@ yyreduce:
   case 26:
 
 /* Line 1455 of yacc.c  */
-#line 336 "ftpcmd.y"
+#line 346 "ftpcmd.y"
     {
 			if ((yyvsp[(2) - (3)].i))
 				cwd(cred.homedir);
@@ -1996,7 +1986,7 @@ yyreduce:
   case 27:
 
 /* Line 1455 of yacc.c  */
-#line 341 "ftpcmd.y"
+#line 351 "ftpcmd.y"
     {
 			if ((yyvsp[(2) - (5)].i) && (yyvsp[(4) - (5)].s) != NULL)
 				cwd((yyvsp[(4) - (5)].s));
@@ -2007,7 +1997,7 @@ yyreduce:
   case 28:
 
 /* Line 1455 of yacc.c  */
-#line 347 "ftpcmd.y"
+#line 357 "ftpcmd.y"
     {
 			help(cmdtab, (char *) 0);
 		}
@@ -2016,7 +2006,7 @@ yyreduce:
   case 29:
 
 /* Line 1455 of yacc.c  */
-#line 351 "ftpcmd.y"
+#line 361 "ftpcmd.y"
     {
 			char *cp = (yyvsp[(3) - (4)].s);
 
@@ -2037,7 +2027,7 @@ yyreduce:
   case 30:
 
 /* Line 1455 of yacc.c  */
-#line 367 "ftpcmd.y"
+#line 377 "ftpcmd.y"
     {
 			reply(200, "NOOP command successful.");
 		}
@@ -2046,7 +2036,7 @@ yyreduce:
   case 31:
 
 /* Line 1455 of yacc.c  */
-#line 371 "ftpcmd.y"
+#line 381 "ftpcmd.y"
     {
 			if ((yyvsp[(2) - (5)].i) && (yyvsp[(4) - (5)].s) != NULL)
 				makedir((yyvsp[(4) - (5)].s));
@@ -2057,7 +2047,7 @@ yyreduce:
   case 32:
 
 /* Line 1455 of yacc.c  */
-#line 377 "ftpcmd.y"
+#line 387 "ftpcmd.y"
     {
 			if ((yyvsp[(2) - (5)].i) && (yyvsp[(4) - (5)].s) != NULL)
 				removedir((yyvsp[(4) - (5)].s));
@@ -2068,7 +2058,7 @@ yyreduce:
   case 33:
 
 /* Line 1455 of yacc.c  */
-#line 383 "ftpcmd.y"
+#line 393 "ftpcmd.y"
     {
 			if ((yyvsp[(2) - (3)].i))
 				pwd();
@@ -2078,7 +2068,7 @@ yyreduce:
   case 34:
 
 /* Line 1455 of yacc.c  */
-#line 388 "ftpcmd.y"
+#line 398 "ftpcmd.y"
     {
 			if ((yyvsp[(2) - (3)].i))
 				cwd("..");
@@ -2088,7 +2078,7 @@ yyreduce:
   case 35:
 
 /* Line 1455 of yacc.c  */
-#line 393 "ftpcmd.y"
+#line 403 "ftpcmd.y"
     {
 			help(sitetab, (char *) 0);
 		}
@@ -2097,7 +2087,7 @@ yyreduce:
   case 36:
 
 /* Line 1455 of yacc.c  */
-#line 397 "ftpcmd.y"
+#line 407 "ftpcmd.y"
     {
 			help(sitetab, (yyvsp[(5) - (6)].s));
 			free ((yyvsp[(5) - (6)].s));
@@ -2107,7 +2097,7 @@ yyreduce:
   case 37:
 
 /* Line 1455 of yacc.c  */
-#line 402 "ftpcmd.y"
+#line 412 "ftpcmd.y"
     {
 			int oldmask;
 
@@ -2122,7 +2112,7 @@ yyreduce:
   case 38:
 
 /* Line 1455 of yacc.c  */
-#line 412 "ftpcmd.y"
+#line 422 "ftpcmd.y"
     {
 			int oldmask;
 
@@ -2142,7 +2132,7 @@ yyreduce:
   case 39:
 
 /* Line 1455 of yacc.c  */
-#line 427 "ftpcmd.y"
+#line 437 "ftpcmd.y"
     {
 			if ((yyvsp[(4) - (9)].i) && ((yyvsp[(8) - (9)].s) != NULL)) {
 				if ((yyvsp[(6) - (9)].i) > 0777)
@@ -2160,7 +2150,7 @@ yyreduce:
   case 40:
 
 /* Line 1455 of yacc.c  */
-#line 440 "ftpcmd.y"
+#line 450 "ftpcmd.y"
     {
 			reply(200,
 			    "Current IDLE time limit is %d seconds; max %d",
@@ -2171,7 +2161,7 @@ yyreduce:
   case 41:
 
 /* Line 1455 of yacc.c  */
-#line 446 "ftpcmd.y"
+#line 456 "ftpcmd.y"
     {
 		    	if ((yyvsp[(3) - (7)].i)) {
 			    if ((yyvsp[(6) - (7)].i) < 30 || (yyvsp[(6) - (7)].i) > maxtimeout) {
@@ -2192,7 +2182,7 @@ yyreduce:
   case 42:
 
 /* Line 1455 of yacc.c  */
-#line 462 "ftpcmd.y"
+#line 472 "ftpcmd.y"
     {
 			if ((yyvsp[(2) - (5)].i) && (yyvsp[(4) - (5)].s) != NULL)
 				store((yyvsp[(4) - (5)].s), "w", 1);
@@ -2203,7 +2193,7 @@ yyreduce:
   case 43:
 
 /* Line 1455 of yacc.c  */
-#line 468 "ftpcmd.y"
+#line 478 "ftpcmd.y"
     {
 		        const char *sys_type; /* Official rfc-defined os type.  */
 			char *version = 0; /* A more specific type. */
@@ -2245,7 +2235,7 @@ yyreduce:
   case 44:
 
 /* Line 1455 of yacc.c  */
-#line 513 "ftpcmd.y"
+#line 523 "ftpcmd.y"
     {
 			if ((yyvsp[(2) - (5)].i) && (yyvsp[(4) - (5)].s) != NULL)
 				sizecmd((yyvsp[(4) - (5)].s));
@@ -2256,7 +2246,7 @@ yyreduce:
   case 45:
 
 /* Line 1455 of yacc.c  */
-#line 529 "ftpcmd.y"
+#line 539 "ftpcmd.y"
     {
 			if ((yyvsp[(2) - (5)].i) && (yyvsp[(4) - (5)].s) != NULL) {
 				struct stat stbuf;
@@ -2282,7 +2272,7 @@ yyreduce:
   case 46:
 
 /* Line 1455 of yacc.c  */
-#line 550 "ftpcmd.y"
+#line 560 "ftpcmd.y"
     {
 			reply(221, "Goodbye.");
 			dologout(0);
@@ -2292,7 +2282,7 @@ yyreduce:
   case 47:
 
 /* Line 1455 of yacc.c  */
-#line 555 "ftpcmd.y"
+#line 565 "ftpcmd.y"
     {
 			yyerrok;
 		}
@@ -2301,7 +2291,7 @@ yyreduce:
   case 48:
 
 /* Line 1455 of yacc.c  */
-#line 561 "ftpcmd.y"
+#line 571 "ftpcmd.y"
     {
 			restart_point = (off_t) 0;
 			if ((yyvsp[(2) - (5)].i) && (yyvsp[(4) - (5)].s)) {
@@ -2316,7 +2306,7 @@ yyreduce:
   case 49:
 
 /* Line 1455 of yacc.c  */
-#line 571 "ftpcmd.y"
+#line 581 "ftpcmd.y"
     {
 		        free (fromname);
 			fromname = (char *) 0;
@@ -2332,7 +2322,7 @@ yyreduce:
   case 51:
 
 /* Line 1455 of yacc.c  */
-#line 589 "ftpcmd.y"
+#line 599 "ftpcmd.y"
     {
 			(yyval.s) = (char *)calloc(1, sizeof(char));
 		}
@@ -2341,7 +2331,7 @@ yyreduce:
   case 54:
 
 /* Line 1455 of yacc.c  */
-#line 602 "ftpcmd.y"
+#line 612 "ftpcmd.y"
     {
 			char *a, *p;
 
@@ -2356,7 +2346,7 @@ yyreduce:
   case 55:
 
 /* Line 1455 of yacc.c  */
-#line 615 "ftpcmd.y"
+#line 625 "ftpcmd.y"
     {
 			(yyval.i) = FORM_N;
 		}
@@ -2365,7 +2355,7 @@ yyreduce:
   case 56:
 
 /* Line 1455 of yacc.c  */
-#line 619 "ftpcmd.y"
+#line 629 "ftpcmd.y"
     {
 			(yyval.i) = FORM_T;
 		}
@@ -2374,7 +2364,7 @@ yyreduce:
   case 57:
 
 /* Line 1455 of yacc.c  */
-#line 623 "ftpcmd.y"
+#line 633 "ftpcmd.y"
     {
 			(yyval.i) = FORM_C;
 		}
@@ -2383,7 +2373,7 @@ yyreduce:
   case 58:
 
 /* Line 1455 of yacc.c  */
-#line 630 "ftpcmd.y"
+#line 640 "ftpcmd.y"
     {
 			cmd_type = TYPE_A;
 			cmd_form = FORM_N;
@@ -2393,7 +2383,7 @@ yyreduce:
   case 59:
 
 /* Line 1455 of yacc.c  */
-#line 635 "ftpcmd.y"
+#line 645 "ftpcmd.y"
     {
 			cmd_type = TYPE_A;
 			cmd_form = (yyvsp[(3) - (3)].i);
@@ -2403,7 +2393,7 @@ yyreduce:
   case 60:
 
 /* Line 1455 of yacc.c  */
-#line 640 "ftpcmd.y"
+#line 650 "ftpcmd.y"
     {
 			cmd_type = TYPE_E;
 			cmd_form = FORM_N;
@@ -2413,7 +2403,7 @@ yyreduce:
   case 61:
 
 /* Line 1455 of yacc.c  */
-#line 645 "ftpcmd.y"
+#line 655 "ftpcmd.y"
     {
 			cmd_type = TYPE_E;
 			cmd_form = (yyvsp[(3) - (3)].i);
@@ -2423,7 +2413,7 @@ yyreduce:
   case 62:
 
 /* Line 1455 of yacc.c  */
-#line 650 "ftpcmd.y"
+#line 660 "ftpcmd.y"
     {
 			cmd_type = TYPE_I;
 		}
@@ -2432,7 +2422,7 @@ yyreduce:
   case 63:
 
 /* Line 1455 of yacc.c  */
-#line 654 "ftpcmd.y"
+#line 664 "ftpcmd.y"
     {
 			cmd_type = TYPE_L;
 			cmd_bytesz = NBBY;
@@ -2442,7 +2432,7 @@ yyreduce:
   case 64:
 
 /* Line 1455 of yacc.c  */
-#line 659 "ftpcmd.y"
+#line 669 "ftpcmd.y"
     {
 			cmd_type = TYPE_L;
 			cmd_bytesz = (yyvsp[(3) - (3)].i);
@@ -2452,7 +2442,7 @@ yyreduce:
   case 65:
 
 /* Line 1455 of yacc.c  */
-#line 665 "ftpcmd.y"
+#line 675 "ftpcmd.y"
     {
 			cmd_type = TYPE_L;
 			cmd_bytesz = (yyvsp[(2) - (2)].i);
@@ -2462,7 +2452,7 @@ yyreduce:
   case 66:
 
 /* Line 1455 of yacc.c  */
-#line 673 "ftpcmd.y"
+#line 683 "ftpcmd.y"
     {
 			(yyval.i) = STRU_F;
 		}
@@ -2471,7 +2461,7 @@ yyreduce:
   case 67:
 
 /* Line 1455 of yacc.c  */
-#line 677 "ftpcmd.y"
+#line 687 "ftpcmd.y"
     {
 			(yyval.i) = STRU_R;
 		}
@@ -2480,7 +2470,7 @@ yyreduce:
   case 68:
 
 /* Line 1455 of yacc.c  */
-#line 681 "ftpcmd.y"
+#line 691 "ftpcmd.y"
     {
 			(yyval.i) = STRU_P;
 		}
@@ -2489,7 +2479,7 @@ yyreduce:
   case 69:
 
 /* Line 1455 of yacc.c  */
-#line 688 "ftpcmd.y"
+#line 698 "ftpcmd.y"
     {
 			(yyval.i) = MODE_S;
 		}
@@ -2498,7 +2488,7 @@ yyreduce:
   case 70:
 
 /* Line 1455 of yacc.c  */
-#line 692 "ftpcmd.y"
+#line 702 "ftpcmd.y"
     {
 			(yyval.i) = MODE_B;
 		}
@@ -2507,7 +2497,7 @@ yyreduce:
   case 71:
 
 /* Line 1455 of yacc.c  */
-#line 696 "ftpcmd.y"
+#line 706 "ftpcmd.y"
     {
 			(yyval.i) = MODE_C;
 		}
@@ -2516,7 +2506,7 @@ yyreduce:
   case 72:
 
 /* Line 1455 of yacc.c  */
-#line 703 "ftpcmd.y"
+#line 713 "ftpcmd.y"
     {
 			/*
 			 * Problem: this production is used for all pathname
@@ -2555,7 +2545,7 @@ yyreduce:
   case 74:
 
 /* Line 1455 of yacc.c  */
-#line 744 "ftpcmd.y"
+#line 754 "ftpcmd.y"
     {
 			int ret, dec, multby, digit;
 
@@ -2583,7 +2573,7 @@ yyreduce:
   case 75:
 
 /* Line 1455 of yacc.c  */
-#line 771 "ftpcmd.y"
+#line 781 "ftpcmd.y"
     {
 			if (cred.logged_in)
 				(yyval.i) = 1;
@@ -2597,7 +2587,7 @@ yyreduce:
 
 
 /* Line 1455 of yacc.c  */
-#line 2601 "ftpcmd.c"
+#line 2591 "ftpcmd.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2809,7 +2799,7 @@ yyreturn:
 
 
 /* Line 1675 of yacc.c  */
-#line 781 "ftpcmd.y"
+#line 791 "ftpcmd.y"
 
 
 #define	CMD	0	/* beginning of command */
