@@ -1,7 +1,7 @@
 /*
   Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-  2003, 2004, 2005, 2006, 2007, 2008, 2009 Free Software Foundation,
-  Inc.
+  2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Free Software
+  Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -60,9 +60,7 @@
 #include <sys/stat.h>
 #include <sys/ioctl.h>
 #include <sys/socket.h>
-#ifdef HAVE_SYS_WAIT_H
-# include <sys/wait.h>
-#endif
+#include <sys/wait.h>
 
 #include <netinet/in.h>
 #ifdef HAVE_NETINET_IN_SYSTM_H
@@ -91,16 +89,8 @@
 #include <stdlib.h>
 #include <string.h>
 #include <syslog.h>
-#ifdef TIME_WITH_SYS_TIME
-# include <sys/time.h>
-# include <time.h>
-#else
-# ifdef HAVE_SYS_TIME_H
-#  include <sys/time.h>
-# else
-#  include <time.h>
-# endif
-#endif
+#include <sys/time.h>
+#include <time.h>
 #include <unistd.h>
 #ifdef HAVE_MMAP
 # include <sys/mman.h>
@@ -193,11 +183,11 @@ off_to_str (off_t off)
     next_buf = bufs;
 
   if (sizeof (off) > sizeof (long))
-    sprintf (*next_buf, "%qd", off);
+    sprintf (*next_buf, "%qd", (long long int) off);
   else if (sizeof (off) == sizeof (long))
     sprintf (*next_buf, "%ld", off);
   else
-    sprintf (*next_buf, "%d", off);
+    sprintf (*next_buf, "%d", (int) off);
 
   return *next_buf++;
 }
@@ -237,8 +227,9 @@ char proctitle[LINE_MAX];	/* initial part of title */
 			   off_to_str (cnt)); \
 	}
 
+extern int yyparse (void);
+
 static void ack (const char *);
-static void authentication_setup (const char *);
 #ifdef HAVE_LIBWRAP
 static int check_host (struct sockaddr *sa);
 #endif
@@ -1487,11 +1478,7 @@ void
 reply (int n, const char *fmt, ...)
 {
   va_list ap;
-#if defined(HAVE_STDARG_H) && defined(__STDC__) && __STDC__
   va_start (ap, fmt);
-#else
-  va_start (ap);
-#endif
   printf ("%d ", n);
   vprintf (fmt, ap);
   printf ("\r\n");
@@ -1507,11 +1494,7 @@ void
 lreply (int n, const char *fmt, ...)
 {
   va_list ap;
-#if defined(HAVE_STDARG_H) && defined(__STDC__) && __STDC__
   va_start (ap, fmt);
-#else
-  va_start (ap);
-#endif
   printf ("%d- ", n);
   vprintf (fmt, ap);
   printf ("\r\n");
