@@ -1,7 +1,7 @@
 /*
   Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-  2003, 2004, 2005, 2006, 2007, 2008, 2009 Free Software Foundation,
-  Inc.
+  2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Free Software
+  Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -55,9 +55,7 @@
 #endif
 
 #include <sys/types.h>
-#ifdef HAVE_SYS_WAIT_H
-# include <sys/wait.h>
-#endif
+#include <sys/wait.h>
 
 #include <errno.h>
 #include <signal.h>
