@@ -1,6 +1,6 @@
 /* changeif.c -- change the configuration of a network interface
-  Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009
-  Free Software Foundation, Inc.
+  Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009,
+  2010 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -25,11 +25,7 @@
 
 #include <stdio.h>
 #include <errno.h>
-#if HAVE_STRING_H
-# include <string.h>
-#else
-# include <strings.h>
-#endif
+#include <string.h>
 
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -188,6 +184,31 @@ set_metric (int sfd, struct ifreq *ifr, int metric)
 #endif
 }
 
+int
+set_flags (int sfd, struct ifreq *ifr, int setflags, int clrflags)
+{
+#if !defined (SIOCGIFFLAGS) || !defined (SIOCSIFFLAGS)
+  error (0, 0,
+         "don't know how to set the interface flags on this system");
+  return -1;
+#else
+  struct ifreq tifr = *ifr;
+
+  if (ioctl (sfd, SIOCGIFFLAGS, &tifr) < 0)
+    {
+      error (0, errno, "SIOCGIFFLAGS failed");
+      return -1;
+    }
+  ifr->ifr_flags = (tifr.ifr_flags | setflags) & ~clrflags;
+  if (ioctl (sfd, SIOCSIFFLAGS, ifr) < 0)
+    {
+      error (0, errno, "SIOCSIFFLAGS failed");
+      return -1;
+    }
+  return 0;
+#endif
+}
+
 int
 configure_if (int sfd, struct ifconfig *ifp)
 {
@@ -212,6 +233,8 @@ configure_if (int sfd, struct ifconfig *ifp)
     err = set_metric (sfd, &ifr, ifp->metric);
   if (!err && ifp->valid & IF_VALID_SYSTEM)
     err = system_configure (sfd, &ifr, ifp->system);
+  if (!err && (ifp->setflags || ifp->clrflags))
+    err = set_flags (sfd, &ifr, ifp->setflags, ifp->clrflags);
   if (!err && ifp->valid & IF_VALID_FORMAT)
     print_interface (sfd, ifp->name, &ifr, ifp->format);
   return err;
