@@ -1,6 +1,6 @@
 /*
-  Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009
-  Free Software Foundation, Inc.
+  Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009,
+  2010 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -44,11 +44,18 @@ const char *if_flagtoname (int flag, const char *avoid);
 
 /* Return the flag mask corresponding to flag name NAME.  If no flag
    with this name is found, return 0.  */
-int if_nametoflag (const char *name);
+int if_nametoflag (const char *name, size_t len, int *prev);
+int if_nameztoflag (const char *name, int *prev);
 
 /* Print the flags in FLAGS, using AVOID as in if_flagtoname, and
    SEPERATOR between individual flags.  Returns the number of
    characters printed.  */
 int print_if_flags (int flags, const char *avoid, char seperator);
 
+char *if_list_flags (const char *prefix);
+
+/* Size of the buffer for the if_format_flags call */
+# define IF_FORMAT_FLAGS_BUFSIZE 15
+void if_format_flags (int flags, char *buf, size_t size);
+
 #endif
