@@ -1,6 +1,6 @@
 /*
-  Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009
-  Free Software Foundation, Inc.
+  Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009,
+  2010 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -49,12 +49,13 @@ if_nametoindex (const char *ifname)
     int fd = socket (AF_INET, SOCK_DGRAM, 0);
     if (fd >= 0)
       {
+	int rc;
 	struct ifreq ifr;
 	strncpy (ifr.ifr_name, ifname, sizeof (ifr.ifr_name));
 	ifr.ifr_name[IFNAMSIZ - 1] = '\0';
-	result = ioctl (fd, SIOCGIFINDEX, &ifr);
+	rc = ioctl (fd, SIOCGIFINDEX, &ifr);
 	close (fd);
-	if (result == 0)
+	if (rc == 0)
 	  return ifr.ifr_index;
       }
   }
