@@ -1,6 +1,6 @@
 /* ifconfig.c -- network interface configuration utility
-  Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009
-  Free Software Foundation, Inc.
+  Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009,
+  2010 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -27,15 +27,9 @@
 #include <stdio.h>
 #include <errno.h>
 
-#if HAVE_UNISTD_H
-# include <unistd.h>
-#endif
+#include <unistd.h>
 
-#if HAVE_STRING_H
-# include <string.h>
-#else
-# include <strings.h>
-#endif
+#include <string.h>
 
 #if STDC_HEADERS
 # include <stdlib.h>
@@ -69,15 +63,13 @@ main (int argc, char *argv[])
       exit (1);
     }
 
-  ifp = ifs;
-  while (ifp - ifs < nifs)
+  for (ifp = ifs; ifp < ifs + nifs; ifp++)
     {
       err = configure_if (sfd, ifp);
       if (err)
 	break;
-      ifp++;
     }
 
   close (sfd);
-  return (err);
+  return err;
 }
