@@ -1,6 +1,6 @@
 /*
-  Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009
-  Free Software Foundation, Inc.
+  Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009,
+  2010 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -30,6 +30,9 @@
 # include <progname.h>
 # include <error.h>
 # include <argp.h>
+# define obstack_chunk_alloc malloc
+# define obstack_chunk_free free
+# include <obstack.h>
 # include <libinetutils.h>
 
 /* XXX */
