@@ -1,6 +1,6 @@
 /*
-  Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009
-  Free Software Foundation, Inc.
+  Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009,
+  2010 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -74,9 +74,16 @@ void format_handler (const char *name, format_data_t form, int argc,
 		     char *argv[]);
 
 void fh_nothing (format_data_t form, int argc, char *argv[]);
+void fh_format_query (format_data_t form, int argc, char *argv[]);
+void fh_docstr (format_data_t form, int argc, char *argv[]);
+void fh_defn (format_data_t form, int argc, char *argv[]);
+void fh_foreachformat (format_data_t form, int argc, char *argv[]);
+void fh_verbose_query (format_data_t form, int argc, char *argv[]);
 void fh_newline (format_data_t form, int argc, char *argv[]);
 void fh_tabulator (format_data_t form, int argc, char *argv[]);
+void fh_rep (format_data_t form, int argc, char *argv[]);
 void fh_first (format_data_t form, int argc, char *argv[]);
+void fh_ifdisplay_query (format_data_t form, int argc, char *argv[]);
 void fh_tab (format_data_t form, int argc, char *argv[]);
 void fh_join (format_data_t form, int argc, char *argv[]);
 void fh_exists_query (format_data_t form, int argc, char *argv[]);
