@@ -1,6 +1,6 @@
 /* xgetdomainname.c -- Return the NIS domain name, without size limitations.
-   Copyright (C) 1992, 1996, 2000-2001, 2003-2004, 2006, 2008 Free Software
-   Foundation, Inc.
+   Copyright (C) 1992, 1996, 2000-2001, 2003-2004, 2006, 2008-2010 Free
+   Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
