@@ -1,6 +1,6 @@
 /* cleansess.c - Clean up the pty and frob utmp/wtmp accordingly after logout
   Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004,
-  2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+  2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -25,16 +25,8 @@
 
 #include <unistd.h>
 #include <sys/types.h>
-#ifdef TIME_WITH_SYS_TIME
-# include <sys/time.h>
-# include <time.h>
-#else
-# ifdef HAVE_SYS_TIME_H
-#  include <sys/time.h>
-# else
-#  include <time.h>
-# endif
-#endif
+#include <sys/time.h>
+#include <time.h>
 #ifdef HAVE_UTMP_H
 # include <utmp.h>
 #else
@@ -43,9 +35,7 @@
 #  define utmp utmpx		/* make utmpx look more like utmp */
 # endif
 #endif
-#ifdef HAVE_STRING_H
-# include <string.h>
-#endif
+#include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 
