@@ -1,6 +1,6 @@
 /* localhost.c - A slightly more convenient wrapper for gethostname
   Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004,
-  2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+  2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -27,9 +27,7 @@
 #ifdef HAVE_MALLOC_H
 # include <malloc.h>
 #endif
-#if defined(STDC_HEADERS) || defined(HAVE_STDLIB_H)
-# include <stdlib.h>
-#endif
+#include <stdlib.h>
 #include <stdint.h>
 #include <string.h>
 #include <errno.h>
