@@ -1,6 +1,6 @@
 /* setsig.c - Set a signal handler, trying to turning on the SA_RESTART bit
   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
-  2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+  2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -23,9 +23,7 @@
 # include <config.h>
 #endif
 
-#ifdef HAVE_STDLIB_H
-# include <stdlib.h>
-#endif
+#include <stdlib.h>
 
 #include <signal.h>
 
