@@ -1,6 +1,6 @@
 /*
   Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
-  2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Free Software
+  2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Free Software
   Foundation, Inc.
 
   This file is part of GNU Inetutils.
@@ -77,9 +77,7 @@
 # include <signal.h>
 # define AUTH_NAMES
 # include <arpa/telnet.h>
-# ifdef HAVE_STDLIB_H
-#  include <stdlib.h>
-# endif
+# include <stdlib.h>
 # ifdef	NO_STRING_H
 #  include <strings.h>
 # else
