@@ -1,6 +1,6 @@
 /*
   Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
-  2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Free Software
+  2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Free Software
   Foundation, Inc.
 
   This file is part of GNU Inetutils.
@@ -60,9 +60,7 @@ extern Shishi *shishi_handle;
 #   endif
 #   include <arpa/telnet.h>
 #   include <stdio.h>
-#   ifdef HAVE_STDLIB_H
-#    include <stdlib.h>
-#   endif
+#   include <stdlib.h>
 
 #   include "encrypt.h"
 #   include "key-proto.h"
@@ -81,7 +79,7 @@ extern int encrypt_debug_mode;
 #   define FAILED		-1
 
 
-#include <string.h>
+#   include <string.h>
 
 struct fb
 {
