@@ -1,6 +1,6 @@
 /*
   Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
-  2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Free Software
+  2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Free Software
   Foundation, Inc.
 
   This file is part of GNU Inetutils.
@@ -79,17 +79,11 @@
 # include "encrypt.h"
 # include "misc.h"
 
-# ifdef HAVE_STDLIB_H
-#  include <stdlib.h>
-# endif
-# ifdef	NO_STRING_H
-#  include <strings.h>
-# else
-#  include <string.h>
-# endif
+# include <stdlib.h>
+# include <string.h>
 
-#include <stdio.h>
-#include "genget.h"
+# include <stdio.h>
+# include "genget.h"
 
 /*
  * These functions pointers point to the current routines
