@@ -1,6 +1,6 @@
 /*
   Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
-  2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Free Software
+  2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Free Software
   Foundation, Inc.
 
   This file is part of GNU Inetutils.
@@ -77,14 +77,8 @@
 # include <stdio.h>
 # include <des.h>		/* BSD wont include this in krb.h, so we do it here */
 # include <krb.h>
-# ifdef HAVE_STDLIB_H
-#  include <stdlib.h>
-# endif
-# ifdef	NO_STRING_H
-#  include <strings.h>
-# else
-#  include <string.h>
-# endif
+# include <stdlib.h>
+# include <string.h>
 
 # include "encrypt.h"
 # include "auth.h"
