@@ -1,6 +1,6 @@
 /*
   Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
-  2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Free Software
+  2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Free Software
   Foundation, Inc.
 
   This file is part of GNU Inetutils.
@@ -33,11 +33,7 @@
 # include <netdb.h>
 # include <ctype.h>
 # include <syslog.h>
-# ifdef  HAVE_STRING_H
-#  include <string.h>
-# else
-#  include <strings.h>
-# endif
+# include <string.h>
 
 # include "auth.h"
 # include "misc.h"
