@@ -1,6 +1,6 @@
 /*
   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
-  2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+  2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -65,7 +65,6 @@
 #if defined(RSA_ENCPWD) || defined(KRB4_ENCPWD)
 
 # include <stdio.h>
-# include <strings.h>
 # include <sys/ioctl.h>
 # include <signal.h>
 # include <setjmp.h>
