@@ -1,6 +1,6 @@
 /*
-  Copyright (C) 2005, 2006, 2007, 2008, 2009 Free Software Foundation,
-  Inc.
+  Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010 Free Software
+  Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
