@@ -1,6 +1,6 @@
 /*
-  Copyright (C) 2005, 2006, 2007, 2008, 2009 Free Software Foundation,
-  Inc.
+  Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010 Free Software
+  Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -158,4 +158,3 @@ void ping_set_sockopt (PING * ping, int opt, void *val, int valsize);
 void ping_set_interval (PING * ping, size_t interval);
 void ping_unset_data (PING * p);
 int ping_timeout_p (struct timeval *start_time, int timeout);
-
