@@ -1,6 +1,7 @@
 /*
   Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
-  2004, 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+  2004, 2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation,
+  Inc.
 
   This file is part of GNU Inetutils.
 
@@ -54,16 +55,8 @@
 
 #include <sys/types.h>
 #include <sys/socket.h>
-#ifdef TIME_WITH_SYS_TIME
-# include <sys/time.h>
-# include <time.h>
-#else
-# ifdef HAVE_SYS_TIME_H
-#  include <sys/time.h>
-# else
-#  include <time.h>
-# endif
-#endif
+#include <sys/time.h>
+#include <time.h>
 #include <signal.h>
 #include <netinet/in.h>
 #ifdef HAVE_OSOCKADDR_H
@@ -119,6 +112,8 @@ announce_invite ()
   /* leave the actual invitation on my talk daemon */
   ctl_transact (my_machine_addr, msg, LEAVE_INVITE, &response);
   local_id = response.id_num;
+
+  return 0;
 }
 
 /*
@@ -187,6 +182,8 @@ invite_remote ()
   msg.id_num = htonl (remote_id);
   ctl_transact (his_machine_addr, msg, DELETE, &response);
   invitation_waiting = 0;
+
+  return 0;
 }
 
 /*
@@ -213,4 +210,6 @@ send_delete ()
 	      (struct sockaddr *) &daemon_addr,
 	      sizeof (daemon_addr)) != sizeof (msg))
     perror ("send_delete (local)");
+
+  return 0;
 }
