@@ -1,6 +1,6 @@
 /*
   Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004,
-  2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+  2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -162,4 +162,3 @@ talkd_run (int fd)
 	}
     }
 }
-
