@@ -1,6 +1,7 @@
 /*
   Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
-  2004, 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+  2004, 2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation,
+  Inc.
 
   This file is part of GNU Inetutils.
 
@@ -62,24 +63,16 @@
 #include <sys/socket.h>
 #include <netinet/in.h>
 
-#ifdef HAVE_FCNTL_H
-# include <fcntl.h>
-#endif /* CRAY */
+#include <fcntl.h>
 
 #include <signal.h>
 #include <netdb.h>
 #include <ctype.h>
 #include <pwd.h>
-#if defined(HAVE_STDARG_H) && defined(__STDC__) && __STDC__
-# include <stdarg.h>
-#else
-# include <varargs.h>
-#endif
+#include <stdarg.h>
 #include <errno.h>
 
-#if defined(STDC_HEADERS) || defined(HAVE_STDLIB_H)
-# include <stdlib.h>
-#endif
+#include <stdlib.h>
 #ifdef HAVE_MALLOC_H
 # include <malloc.h>
 #endif
@@ -97,6 +90,9 @@
 #include "defines.h"
 #include "types.h"
 
+#include "xalloc.h"
+#include "xvasprintf.h"
+
 #if !defined(CRAY) && !defined(sysV88)
 # ifdef HAVE_NETINET_IN_SYSTM_H
 #  include <netinet/in_systm.h>
@@ -2842,26 +2838,13 @@ static Command cmdtab2[] = {
  */
 
 static int
-#if defined(HAVE_STDARG_H) && defined(__STDC__) && __STDC__
 call (intrtn_t routine, ...)
-#else
-call (va_alist)
-     va_dcl
-#endif
 {
   va_list ap;
-#if !(defined(HAVE_STDARG_H) && defined(__STDC__) && __STDC__)
-  intrtn_t routine;
-#endif
   char *args[100];
   int argno = 0;
 
-#if defined(HAVE_STDARG_H) && defined(__STDC__) && __STDC__
   va_start (ap, routine);
-#else
-  va_start (ap);
-  routine = (va_arg (ap, intrtn_t));
-#endif
   while ((args[argno++] = va_arg (ap, char *)) != 0)
     {
       ;
@@ -3008,7 +2991,6 @@ help (int argc, char *argv[])
 }
 
 static char *rcname = 0;
-static char rcbuf[128];
 
 static void
 cmdrc (char *m1, char *m2)
@@ -3018,23 +3000,17 @@ cmdrc (char *m1, char *m2)
   int gotmachine = 0;
   int l1 = strlen (m1);
   int l2 = strlen (m2);
-  char m1save[64];
 
   if (skiprc)
     return;
 
-  strcpy (m1save, m1);
-  m1 = m1save;
-
   if (rcname == 0)
     {
-      rcname = getenv ("HOME");
-      if (rcname)
-	strcpy (rcbuf, rcname);
+      const char *home = getenv ("HOME");
+      if (home)
+        rcname = xasprintf ("%s/.telnetrc", home);
       else
-	rcbuf[0] = '\0';
-      strcat (rcbuf, "/.telnetrc");
-      rcname = rcbuf;
+        rcname = xstrdup ("/.telnetrc");
     }
 
   if ((rcfile = fopen (rcname, "r")) == 0)
