@@ -1,6 +1,7 @@
 /*
   Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
-  2004, 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+  2004, 2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation,
+  Inc.
 
   This file is part of GNU Inetutils.
 
@@ -57,28 +58,16 @@
 
 #include <fcntl.h>
 #include <sys/types.h>
-#ifdef TIME_WITH_SYS_TIME
-# include <sys/time.h>
-# include <time.h>
-#else
-# ifdef HAVE_SYS_TIME_H
-#  include <sys/time.h>
-# else
-#  include <time.h>
-# endif
-#endif
+#include <sys/time.h>
+#include <time.h>
 #include <sys/socket.h>
 #include <signal.h>
 #include <errno.h>
 #include <arpa/telnet.h>
-#ifdef HAVE_SYS_SELECT_H
-# include <sys/select.h>
-#endif
+#include <sys/select.h>
 
 #include "ring.h"
 
-#include "fdset.h"
-
 #include "defines.h"
 #include "externs.h"
 #include "types.h"
@@ -1319,7 +1308,8 @@ process_rings (int netin, int netout, int netex, int ttyin, int ttyout,
   if (FD_ISSET (tin, &ibits))
     {
       FD_CLR (tin, &ibits);
-      c = TerminalRead (ttyiring.supply, ring_empty_consecutive (&ttyiring));
+      c = TerminalRead ((char *)ttyiring.supply,
+                        ring_empty_consecutive (&ttyiring));
       if (c < 0 && errno == EIO)
 	c = 0;
       if (c < 0 && errno == EWOULDBLOCK)
