@@ -1,6 +1,7 @@
 /*
   Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
-  2004, 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+  2004, 2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation,
+  Inc.
 
   This file is part of GNU Inetutils.
 
@@ -63,9 +64,7 @@
 #include <arpa/telnet.h>
 
 #include <ctype.h>
-#if defined(STDC_HEADERS) || defined(HAVE_STDLIB_H)
-# include <stdlib.h>
-#endif
+#include <stdlib.h>
 
 #include <libinetutils.h>
 
