@@ -1,6 +1,6 @@
 /*
   Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004,
-  2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+  2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -35,9 +35,7 @@
 #include <syslog.h>
 #include <string.h>
 #include <ctype.h>
-#ifdef HAVE_STRINGS_H
-# include <strings.h>
-#endif
+#include <strings.h>
 #ifdef HAVE_SYS_FILIO_H
 # include <sys/filio.h>
 #endif
