@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# Copyright (C) 2009 Free Software Foundation, Inc.
+# Copyright (C) 2009, 2010 Free Software Foundation, Inc.
 #
 # This file is part of GNU Inetutils.
 #
@@ -17,7 +17,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see `http://www.gnu.org/licenses/'.
 
-TRACEROUTE=${TRACEROUTE:-../traceroute/traceroute$EXEEXT}
+TRACEROUTE=${TRACEROUTE:-../src/traceroute$EXEEXT}
 
 if [ $VERBOSE ]; then
     set -x
